@@ -372,7 +372,7 @@ char *smart_strtok(
 
   start = *ptrPtr;
 
-  tmpLineSize = (line == NULL) ? strlen(*ptrPtr + 1) : strlen(line) + 1;
+  tmpLineSize = (line == NULL) ? strlen(*ptrPtr) + 1 : strlen(line) + 1;
   tmpLine = (char *)malloc(tmpLineSize * sizeof(char));
 
   tmpLine[0] = '\0';
