@@ -78,21 +78,14 @@
 */
 
 /*
- * @(#) $Id: dis_init.h 2367 2008-09-03 17:17:34Z josh $
+ * @(#) $Id: dis_init.h 3230 2009-11-05 00:12:42Z ataufer $
  */
 
-#ifdef __STDC__
-#define A_(x) x
-#else
-#define const
-#define volatile
-#define A_(x) ()
-#endif
 
-extern int (*dis_getc) A_((int stream));
-extern int (*dis_puts) A_((int stream, const char *string, size_t count));
-extern int (*dis_gets) A_((int stream, char *string, size_t count));
-extern int (*disr_skip) A_((int stream, size_t nskips));
-extern int (*disw_commit) A_((int stream, int commit));
-extern int (*disr_commit) A_((int stream, int commit));
+extern int (*dis_getc) (int stream);
+extern int (*dis_puts) (int stream, const char *string, size_t count);
+extern int (*dis_gets) (int stream, char *string, size_t count);
+extern int (*disr_skip) (int stream, size_t nskips);
+extern int (*disw_commit) (int stream, int commit);
+extern int (*disr_commit) (int stream, int commit);
 
