@@ -161,6 +161,7 @@
 #define ATTR_reported    "reported"
 #define ATTR_intcmd      "inter_cmd"
 #define ATTR_P           "proxy_user"
+#define ATTR_exec_gpus   "exec_gpus"
 
 #ifdef USEJOBCREATE
 #define ATTR_pagg         "pagg_id"
@@ -285,6 +286,7 @@
 #ifdef MUNGE_AUTH
   #define ATTR_authusers       "authorized_users"
 #endif
+#define ATTR_moabarraycompatible "moab_array_compatible"
 /* additional node "attributes" names */
 
 #define ATTR_NODE_state         "state"
@@ -294,6 +296,7 @@
 #define ATTR_NODE_jobs          "jobs"
 #define ATTR_NODE_status        "status"
 #define ATTR_NODE_note          "note"
+#define ATTR_NODE_gpus           "gpus"
 
 /* notification email formating */
 #define ATTR_mailsubjectfmt "mail_subject_fmt"
