@@ -145,7 +145,7 @@
 **  quota  quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3151 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3230 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -193,9 +193,9 @@ extern time_t   last_scan;
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern unsigned int reqnum;
 extern double cputfactor;
@@ -209,16 +209,16 @@ extern  int     ignmem;
 /*
 ** local functions and data
 */
-static char *resi  A_((struct rm_attribute *attrib));
-static char *totmem  A_((struct rm_attribute *attrib));
-static char *availmem A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *ncpus  A_((struct rm_attribute *attrib));
-static char *walltime A_((struct rm_attribute *attrib));
-static char *quota  A_((struct rm_attribute *attrib));
+static char *resi(struct rm_attribute *attrib);
+static char *totmem(struct rm_attribute *attrib);
+static char *availmem(struct rm_attribute *attrib);
+static char *physmem(struct rm_attribute *attrib);
+static char *ncpus(struct rm_attribute *attrib);
+static char *walltime(struct rm_attribute *attrib);
+static char *quota(struct rm_attribute *attrib);
 
-extern char *loadave A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
+extern char *loadave(struct rm_attribute *attrib);
+extern char *nullproc(struct rm_attribute *attrib);
 
 
 /*
