@@ -607,6 +607,7 @@ int status_nodeattrib(
 
   int             *bad)         /*if node-attribute error, record it's*/
 /*list position here                 */
+
   {
   int   i;
   int   rc = 0;  /*return code, 0 == success*/
@@ -635,6 +636,10 @@ int status_nodeattrib(
       atemp[i].at_val.at_long = pnode->nd_nsn;
     else if (!strcmp((padef + i)->at_name, ATTR_NODE_note))
       atemp[i].at_val.at_str  = pnode->nd_note;
+    else if (!strcmp((padef + i)->at_name, ATTR_NODE_gpus))
+      {
+      atemp[i].at_val.at_long  = pnode->nd_ngpus;
+      }
     else
       {
       /*we don't ever expect this*/
@@ -1571,6 +1576,49 @@ int create_pbs_node(
 
 
 
+
+int create_a_gpusubnode(
+    
+  struct pbsnode *pnode)
+
+  {
+  static char *id = "create_a_gpusubnode";
+  struct gpusubn *tmp;
+ 
+  tmp = malloc(sizeof(struct gpusubn) * (1 + pnode->nd_ngpus));
+
+  if (tmp == NULL)
+    {
+    log_err(ENOMEM,id,"Couldn't allocate memory for a subnode. EPIC FAILURE");
+    return(ENOMEM);
+    }
+
+  if (pnode->nd_ngpus > 0)
+    {
+    /* copy old memory to the new place */
+    memcpy(tmp,pnode->nd_gpusn,(sizeof(struct gpusubn) * pnode->nd_ngpus));
+    }
+
+  /* now use the new memory */
+  free(pnode->nd_gpusn);
+  pnode->nd_gpusn = tmp;
+
+  /* initialize the node */
+  pnode->nd_gpusn[pnode->nd_ngpus].pjob = NULL;
+  pnode->nd_gpusn[pnode->nd_ngpus].inuse = FALSE;
+  pnode->nd_gpusn[pnode->nd_ngpus].flag = 0;
+  pnode->nd_gpusn[pnode->nd_ngpus].index = pnode->nd_ngpus;
+
+  /* increment the number of gpu subnodes and gpus free */
+  pnode->nd_ngpus++;
+  pnode->nd_ngpus_free++;
+
+  return(PBSE_NONE);
+  } /* END create_a_gpusubnode() */
+
+
+
+
 /*
  * parse_node_token - parse tokens in the nodes file
  *
@@ -2099,6 +2147,37 @@ static void delete_a_subnode(
 
 
 
+/* 
+ * deletes the last gpu subnode
+ * frees the node and decrements the number to adjust 
+ */
+static void delete_a_gpusubnode(
+
+  struct pbsnode *pnode)
+
+  {
+  struct gpusubn *tmp = pnode->nd_gpusn + (pnode->nd_ngpus - 1);
+
+  if (pnode->nd_ngpus < 1)
+    {
+    /* ERROR, can't free non-existent subnodes */
+    return;
+    }
+
+  if (tmp->inuse == FALSE)
+    pnode->nd_ngpus_free--;
+
+  /* decrement the number of gpu subnodes */
+  pnode->nd_gpusn--;
+
+  /* free the gpu subnode */
+  free(tmp);
+
+  /* DONE */
+  } /* END delete_a_gpusubnode() */
+
+
+
 
 
 /*
@@ -2155,6 +2234,61 @@ node_np_action(
   } /* END node_np_action */
 
 
+
+
+
+int node_gpus_action(
+
+  attribute *new,
+  void      *pnode,
+  int        actmode)
+
+  {
+  struct pbsnode *np = (struct pbsnode *)pnode;
+  int             old_gp;
+  int             new_gp;
+  int             rc = 0;
+
+  switch (actmode)
+    {
+    case ATR_ACTION_NEW:
+      new->at_val.at_long = np->nd_ngpus;
+      break;
+
+    case ATR_ACTION_ALTER:
+      old_gp = np->nd_ngpus;
+      new_gp = new->at_val.at_long;
+
+      if (new_gp <= 0)
+        return PBSE_BADATVAL;
+
+      while (new_gp != old_gp)
+        {
+
+        if (new_gp < old_gp)
+          {
+          delete_a_gpusubnode(pnode);
+          old_gp--;
+          }
+        else
+          {
+          create_a_gpusubnode(pnode);
+          old_gp++;
+          }
+        }
+
+      break;
+
+    default:
+      rc = PBSE_INTERNAL;
+    }
+
+  return(rc);
+  } /* END node_gpus_action() */
+
+
+
+
 /* create_partial_pbs_node - similar to create_pbs_node except there will
    only be a name for the new node and no attributes or properties */
 
