@@ -148,12 +148,14 @@ extern char *msg_script_open;
 
 extern char *acct_file;
 extern char *log_file;
+extern char *job_log_file;
 extern char *path_home;
 extern char *path_acct;
 extern char path_log[];
 extern char *path_priv;
 extern char *path_arrays;
 extern char *path_jobs;
+extern char *path_credentials;
 extern char *path_queues;
 extern char *path_spool;
 extern char *path_svrdb;
@@ -166,6 +168,7 @@ extern char *path_nodestate;
 extern char *path_nodenote;
 extern char *path_nodenote_new;
 extern char *path_checkpoint;
+extern char *path_jobinfo_log;
 
 extern int  queue_rank;
 extern char  server_name[];
@@ -287,7 +290,7 @@ int DArrayFree(
 
 
 /**
- * Append Item onto the end of Array, resizing it if necessary 
+ * Append Item onto the end of Array, resizing it if necessary
  * @param Array (I/O)
  * @param Item (I)
  */
@@ -650,6 +653,8 @@ int pbsd_init(
 
   path_jobs      = build_path(path_priv, PBS_JOBDIR,   suffix_slash);
 
+  path_credentials = build_path(path_priv, PBS_CREDENTIALDIR, suffix_slash);
+
   path_acct  = build_path(path_priv, PBS_ACCT,     suffix_slash);
 
   if(path_svrdb == NULL)
@@ -661,6 +666,8 @@ int pbsd_init(
 
   path_svrlog = build_path(path_home, PBS_LOGFILES, suffix_slash);
 
+  path_jobinfo_log = build_path(path_home, PBS_JOBINFOLOGDIR, suffix_slash);
+
   path_track  = build_path(path_priv, PBS_TRACKING, NULL);
 
   path_nodes  = build_path(path_priv, NODE_DESCRIP, NULL);
@@ -673,7 +680,56 @@ int pbsd_init(
 
   path_nodenote_new = build_path(path_priv, NODE_NOTE, new_tag);
 
+#ifdef SERVER_CHKPTDIR
+  /* need to make sure path ends with a '/' */
+
+  if (*(SERVER_CHKPTDIR + strlen(SERVER_CHKPTDIR) - 1)  == '/')
+    {
+    path_checkpoint = strdup(SERVER_CHKPTDIR);
+    }
+  else
+    {
+    path_checkpoint = malloc(strlen(SERVER_CHKPTDIR) + strlen(suffix_slash) + 1);
+    strcpy (path_checkpoint, SERVER_CHKPTDIR);
+    strcat (path_checkpoint, suffix_slash);
+    }
+
+#else
   path_checkpoint     = build_path(path_home, PBS_CHKPTDIR, suffix_slash);
+#endif
+
+  /* check existance amd make sure it is a directory */
+
+  if (stat(path_checkpoint, &statbuf) < 0)
+    {
+    sprintf(log_buffer,
+            "unable to stat checkpoint directory %s, errno %d (%s)",
+            path_checkpoint,
+            errno,
+            strerror(errno));
+    log_err(errno, "pbs_init", log_buffer);
+
+    return(-1);
+    }
+
+  if (!S_ISDIR(statbuf.st_mode))
+    {
+    sprintf(log_buffer,
+            "checkpoint directory path %s is not a directory",
+            path_checkpoint);
+    log_err(errno, "pbs_init", log_buffer);
+
+    return(-1);
+    }
+
+#ifdef SERVER_CHKPTDIR
+  /* set permissions on checkpoint path, if needed */
+
+	if ((statbuf.st_mode && 01777) != 01777) 
+	  {
+    chmod(path_checkpoint, 01777);
+	  }
+#endif
 
   if (svr_resc_def == NULL)
     {
@@ -696,6 +752,8 @@ int pbsd_init(
 
   rc |= chk_file_sec(path_acct,  1, 0, S_IWGRP | S_IWOTH, 0, EMsg);
 
+  rc |= chk_file_sec(path_credentials,  1, 0, S_IWGRP | S_IWOTH, 0, EMsg);
+
   rc |= chk_file_sec(PBS_ENVIRON, 0, 0, S_IWGRP | S_IWOTH, 1, EMsg);
 
   if (rc != 0)
@@ -785,12 +843,21 @@ int pbsd_init(
     {
     /* Open the server database (save file) and read it in */
 
+#ifdef SERVER_XML
+    if ((rc != 0) || ((rc = svr_recov_xml(path_svrdb, FALSE)) == -1)) 
+      {
+      log_err(rc, "pbsd_init", msg_init_baddb);
+      
+      return(-1);
+      }
+#else
     if ((rc != 0) || ((rc = svr_recov(path_svrdb, FALSE)) == -1)) 
       {
       log_err(rc, "pbsd_init", msg_init_baddb);
-
+      
       return(-1);
       }
+#endif /* SERVER_XML */
 
     if (server.sv_attr[(int)SRV_ATR_resource_assn].at_flags & ATR_VFLAG_SET)
       {
@@ -826,13 +893,19 @@ int pbsd_init(
     0,
     PACKAGE_VERSION);
 
-  /* 6. open accounting file */
+  /* 6. open accounting file and job log file if logging is set */
 
   if (acct_open(acct_file) != 0)
     {
     return(-1);
     }
 
+  if(server.sv_attr[(int)SRV_ATR_RecordJobInfo].at_val.at_long)
+    {
+    job_log_open(job_log_file, path_jobinfo_log);
+    }
+
+
   /* 7. Set up other server and global variables */
 
   if (a_opt_init != -1)
@@ -1060,7 +1133,7 @@ int pbsd_init(
           if ((pjob = job_recov(pdirent->d_name)) != NULL)
             {
             pjob->ji_is_array_template = TRUE;
-            
+
             if (DArrayAppend(&Array,pjob) == FAILURE)
               {
               log_err(ENOMEM,"main","out of memory reloading jobs");
@@ -1202,11 +1275,11 @@ int pbsd_init(
   while (pa != NULL)
     {
     pa->template_job = find_array_template(pa->ai_qs.parent_id);
-    
+
     if (pa->ai_qs.num_cloned != pa->ai_qs.num_jobs)
       {
 
-      /* if we can't finish building the job array then delete whats been done 
+      /* if we can't finish building the job array then delete whats been done
          so far */
       if (pa->template_job == NULL)
         {
@@ -1227,8 +1300,8 @@ int pbsd_init(
         }
       else
         {
-        /* TODO Someone must have been naughty and did a kill -9 on pbs_server, 
-           we might need to validate that the last job was fully initialized 
+        /* TODO Someone must have been naughty and did a kill -9 on pbs_server,
+           we might need to validate that the last job was fully initialized
            before continuing the cloning process. */
         wt = set_task(WORK_Timed, time_now + 1, job_clone_wt, (void*)pa->template_job);
 
@@ -1303,7 +1376,7 @@ int pbsd_init(
 
     log_err(errno,"pbs_init","calloc failure");
 
-    return(-1);	
+    return(-1);
     }
 
   for (i = 0;i < server.sv_tracksize;i++)
@@ -1525,7 +1598,7 @@ static int pbsd_init_job(
     case JOB_SUBSTATE_WAITING:
 
     case JOB_SUBSTATE_PRERUN:
-    
+
     case JOB_SUBSTATE_ARRAY_TEMP:
 
       pbsd_init_reque(pjob, CHANGE_STATE);
@@ -1942,6 +2015,11 @@ static void change_logs(
 
   acct_open(acct_file);
 
+  if(server.sv_attr[(int)SRV_ATR_RecordJobInfo].at_val.at_long)
+    {
+    job_log_open(job_log_file, path_jobinfo_log);
+    }
+
   rpp_dbprt = 1 - rpp_dbprt; /* toggle debug prints for RPP */
 
   return;
@@ -2265,8 +2343,8 @@ int get_svr_attr(
   static char id[] = "get_svr_attr";
   int	 rc;
   char	*suffix_slash = "/";
-  
-  if (type != RECOV_CREATE) 
+
+  if (type != RECOV_CREATE)
     {
     /* Open the server database (save file) and read it in */
 
@@ -2290,14 +2368,22 @@ int get_svr_attr(
         }
       }
 
+#ifdef SERVER_XML
+    if (((rc = chk_save_file(path_svrdb))!= 0) || ((rc = svr_recov_xml(path_svrdb, TRUE)) == -1)) 
+      {
+      log_err(rc, id ,msg_init_baddb);
+      
+      return(-1);
+      }
+#else
     if (((rc = chk_save_file(path_svrdb))!= 0) || ((rc = svr_recov(path_svrdb, TRUE)) == -1)) 
       {
       log_err(rc, id ,msg_init_baddb);
-
+      
       return(-1);
       }
-
-    } 
+#endif /* SERVER_XML */
+    }
 
   return(0);
   }  /* END get_svr_attr() */
