@@ -109,6 +109,7 @@
 #include "svrfunc.h"
 #include "net_connect.h"
 #include "pbs_proto.h"
+#include "array.h"
 
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
@@ -116,27 +117,27 @@
 
 /* External Functions Called: */
 
-extern int                   send_job A_((job *, pbs_net_t, int, int, void (*x)(), struct batch_request *));
-extern void                  set_resc_assigned A_((job *, enum batch_op));
+extern int                   send_job(job *, pbs_net_t, int, int, void (*x)(), struct batch_request *);
+extern void                  set_resc_assigned(job *, enum batch_op);
 
-extern struct batch_request *cpy_stage A_((struct batch_request *, job *, enum job_atr, int));
-void                         stream_eof A_((int, u_long, int));
+extern struct batch_request *cpy_stage(struct batch_request *, job *, enum job_atr, int);
+void                         stream_eof(int, u_long, int);
 extern int                   job_set_wait(attribute *, void *, int);
-extern void                  stat_mom_job A_((job *));
+extern void                  stat_mom_job(job *);
 
 extern int LOGLEVEL;
 
 /* Public Functions in this file */
 
-int  svr_startjob A_((job *, struct batch_request *, char *, char *));
+int  svr_startjob(job *, struct batch_request *, char *, char *);
 
 /* Private Functions local to this file */
 
-static void post_sendmom A_((struct work_task *));
-static int  svr_stagein A_((job *, struct batch_request *, int, int));
-static int  svr_strtjob2 A_((job *, struct batch_request *));
-static job *chk_job_torun A_((struct batch_request *, int));
-static int  assign_hosts A_((job *, char *, int, char *, char *));
+static void post_sendmom(struct work_task *);
+static int  svr_stagein(job *, struct batch_request *, int, int);
+static int  svr_strtjob2(job *, struct batch_request *);
+static job *chk_job_torun(struct batch_request *, int);
+static int  assign_hosts(job *, char *, int, char *, char *);
 
 /* Global Data Items: */
 
@@ -227,6 +228,30 @@ void req_runjob(
     preq = NULL;  /* cleared so we don't try to reuse */
     }
 
+  /* if the job is part of an array, check the slot limit */
+  if ((pjob->ji_arraystruct != NULL) &&
+      (pjob->ji_is_array_template == FALSE))
+    {
+    job_array *pa = pjob->ji_arraystruct;
+    
+    if ((pa->ai_qs.slot_limit < 0) ||
+        (pa->ai_qs.slot_limit > pa->ai_qs.jobs_running))
+      {
+      update_array_values(pa,pjob,pjob->ji_qs.ji_state,aeRun);
+      }
+    else
+      {
+      snprintf(log_buffer,sizeof(log_buffer),
+        "Cannot run job. Array slot limit is %d and there are already %d jobs running\n",
+        pa->ai_qs.slot_limit,
+        pa->ai_qs.jobs_running);
+      
+      req_reject(PBSE_IVALREQ,0,preq,NULL,log_buffer);
+
+      return;
+      }
+    }
+
   /* NOTE:  nodes assigned to job in svr_startjob() */
 
   rc = svr_startjob(pjob, preq, failhost, emsg);
@@ -1023,6 +1048,14 @@ static int svr_strtjob2(
 
   /* if job start timeout attribute is set use its value */
   
+  if (((server.sv_attr[(int)SRV_ATR_JobStartTimeout].at_flags & ATR_VFLAG_SET) != 0)
+          && (server.sv_attr[(int)SRV_ATR_JobStartTimeout].at_val.at_long > 0))
+    {
+    DIS_tcp_settimeout(server.sv_attr[(int)SRV_ATR_JobStartTimeout].at_val.at_long);
+    }
+
+  /* if job start timeout attribute is set use its value */
+  
   if (((server.sv_attr[(int)SRV_ATR_JobStartTimeout].at_flags & ATR_VFLAG_SET) != 0)
           && (server.sv_attr[(int)SRV_ATR_JobStartTimeout].at_val.at_long > 0))
     {
@@ -1412,11 +1445,7 @@ static job *chk_job_torun(
 
   /* where to execute the job */
 
-#ifdef ENABLE_BLCR
-  if (pjob->ji_qs.ji_svrflags & JOB_SVFLG_StagedIn)
-#else
   if (pjob->ji_qs.ji_svrflags & (JOB_SVFLG_CHECKPOINT_FILE | JOB_SVFLG_StagedIn))
-#endif
     {
     /* job has been checkpointed or files already staged in */
     /* in this case, exec_host must be already set          */
@@ -1557,9 +1586,10 @@ static int assign_hosts(
   char  *hosttoalloc = NULL;
   pbs_net_t  momaddr = 0;
   resource *pres;
-  int   rc = 0;
+  int   rc = 0, procs=0;
   extern char  *mom_host;
 
+
   if (EMsg != NULL)
     EMsg[0] = '\0';
 
@@ -1584,6 +1614,7 @@ static int assign_hosts(
     }
   else
     {
+    /* Build our host list from what is in the job attrs */
     pres = find_resc_entry(
              &pjob->ji_wattr[(int)JOB_ATR_resource],
              find_resc_def(svr_resc_def, "neednodes", svr_resc_size));
@@ -1594,6 +1625,22 @@ static int assign_hosts(
 
       hosttoalloc = pres->rs_value.at_val.at_str;
 
+      if ((hosttoalloc == NULL) || (hosttoalloc[0] == '\0'))
+        {
+        return(PBSE_UNKNODEATR);
+        }
+      }
+
+    pres = find_resc_entry(
+             &pjob->ji_wattr[(int)JOB_ATR_resource],
+             find_resc_def(svr_resc_def, "procs", svr_resc_size));
+
+    if (pres != NULL)
+      {
+      /* assign what was in "neednodes" */
+
+      procs = pres->rs_value.at_val.at_long;
+
       if ((hosttoalloc == NULL) || (hosttoalloc[0] == '\0'))
         {
         return(PBSE_UNKNODEATR);
@@ -1651,7 +1698,7 @@ static int assign_hosts(
     {
     if ((rc = is_ts_node(hosttoalloc)) != 0)
       {
-      rc = set_nodes(pjob, hosttoalloc, &list, FailHost, EMsg);
+      rc = set_nodes(pjob, hosttoalloc, procs, &list, FailHost, EMsg);
 
       set_exec_host = 1; /* maybe new VPs, must set */
 
