@@ -105,11 +105,13 @@
 #include "net_connect.h"
 #include "pbs_nodes.h"
 #include "log.h"
+#include "array.h"
 
 /* Global Data Items: */
 
 extern struct server   server;
 extern tlist_head      svr_alljobs;
+extern tlist_head      svr_jobs_array_sum;
 extern tlist_head      svr_queues;
 extern char            server_name[];
 extern attribute_def   svr_attr_def[];
@@ -125,11 +127,11 @@ extern int             LOGLEVEL;
 
 /* Extern Functions */
 
-int status_job A_((job *, struct batch_request *, svrattrl *, tlist_head *, int *));
-int status_attrib A_((svrattrl *, attribute_def *, attribute *, int, int, tlist_head *, int *, int));
-extern int   svr_connect A_((pbs_net_t, unsigned int, void (*)(int), enum conn_type));
-extern int status_nodeattrib(svrattrl *, attribute_def *, struct pbsnode *, int, int, tlist_head *, int*);
-extern int hasprop(struct pbsnode *, struct prop *);
+int status_job(job *, struct batch_request *, svrattrl *, tlist_head *, int *);
+int status_attrib(svrattrl *, attribute_def *, attribute *, int, int, tlist_head *, int *, int);
+extern int  svr_connect(pbs_net_t, unsigned int, void (*)(int), enum conn_type);
+extern int  status_nodeattrib(svrattrl *, attribute_def *, struct pbsnode *, int, int, tlist_head *, int*);
+extern int  hasprop(struct pbsnode *, struct prop *);
 extern void rel_resc(job*);
 
 /* Private Data Definitions */
@@ -138,11 +140,11 @@ static int bad;
 
 /* The following private support functions are included */
 
-static void update_state_ct A_((attribute *, int *, char *));
-static int  status_que A_((pbs_queue *, struct batch_request *, tlist_head *));
-static int  status_node A_((struct pbsnode *, struct batch_request *, tlist_head *));
-static void req_stat_job_step2 A_((struct stat_cntl *));
-static void stat_update A_((struct work_task *));
+static void update_state_ct(attribute *, int *, char *);
+static int  status_que(pbs_queue *, struct batch_request *, tlist_head *);
+static int  status_node(struct pbsnode *, struct batch_request *, tlist_head *);
+static void req_stat_job_step2(struct stat_cntl *);
+static void stat_update(struct work_task *);
 
 #ifndef TMAX_JOB
 #define TMAX_JOB 999999999
@@ -173,6 +175,9 @@ enum TJobStatTypeEnum
   tjstServer,
   tjstTruncatedQueue,
   tjstTruncatedServer,
+  tjstSummarizeArraysServer,
+  tjstSummarizeArraysQueue,
+  tjstArray,
   tjstLAST
   };
 
@@ -210,23 +215,43 @@ void req_stat_job(
 
       type = tjstTruncatedServer;
       }
+    else if (!strncasecmp(preq->rq_extend, "summarize_arrays", strlen("summarize_arrays")))
+      {
+      type = tjstSummarizeArraysServer;
+      }
+
     }    /* END if (preq->rq_extend != NULL) */
 
   if (isdigit((int)*name))
     {
     /* status a single job */
 
-    type = tjstJob;
-
-    if ((pjob = find_job(name)) == NULL)
+    if (is_array(name))
       {
-      rc = PBSE_UNKJOBID;
+      
+      if (type != tjstSummarizeArraysServer)
+        {
+        type = tjstArray;
+        }
+      pjob = find_array_template(name);
       }
+    else
+      {
+      type = tjstJob;
+      if ((pjob = find_job(name)) == NULL)
+        {
+        rc = PBSE_UNKJOBID;
+        }
+      }
+      
+    
     }
   else if (isalpha(name[0]))
     {
     if (type == tjstNONE)
       type = tjstQueue;
+    else if (type == tjstSummarizeArraysServer)
+      type = tjstSummarizeArraysQueue;
     else
       type = tjstTruncatedQueue;
 
@@ -313,8 +338,7 @@ static void req_stat_job_step2(
 
   {
   svrattrl        *pal;
-  job         *pjob;
-  job                  *cpjob;
+  job         *pjob = NULL;
 
   struct batch_request *preq;
 
@@ -331,6 +355,10 @@ static void req_stat_job_step2(
   long                  DTime;  /* delta time - only report full attribute list if J->MTime > DTime */
 
   static svrattrl      *dpal = NULL;
+  
+  int job_array_index = 0;
+  job_array *pa = NULL;
+  
 
   preq   = cntl->sc_origrq;
   type   = (enum TJobStatTypeEnum)cntl->sc_type;
@@ -376,6 +404,11 @@ static void req_stat_job_step2(
       }
     }  /* END if (dpal == NULL) */
 
+  if (type == tjstArray)
+    {
+    pa = get_array(preq->rq_ind.rq_status.rq_id);
+    }
+
   if (!server.sv_attr[(int)SRV_ATR_PollJobs].at_val.at_long)
     {
     /* polljobs not set - indicates we may need to obtain fresh data from
@@ -399,6 +432,14 @@ static void req_stat_job_step2(
         else if (type == tjstQueue)
           {
           pjob = (job *)GET_NEXT(cntl->sc_pque->qu_jobs);
+          }
+        else if (type == tjstArray)
+          {
+          job_array_index = 0;
+          /* increment job_array_index until we find a non-null pointer or hit the end */
+          while (job_array_index < pa->ai_qs.array_size && (pjob = pa->jobs[job_array_index]) == NULL)
+             job_array_index++;
+         
           }
         else
           {
@@ -419,6 +460,14 @@ static void req_stat_job_step2(
           pjob = (job *)GET_NEXT(pjob->ji_jobque);
         else
           pjob = (job *)GET_NEXT(pjob->ji_alljobs);
+          
+        if (type == tjstArray)
+          {
+          pjob = NULL;
+          /* increment job_array_index until we find a non-null pointer or hit the end */
+          while (++job_array_index < pa->ai_qs.array_size && (pjob = pa->jobs[job_array_index]) == NULL)
+            ;
+          }
         }
 
       if (pjob == NULL)
@@ -469,10 +518,27 @@ static void req_stat_job_step2(
    * loop through again
    */
 
+  if (type == tjstSummarizeArraysQueue || type == tjstSummarizeArraysServer)
+    {
+    update_array_statuses();
+    }
+
   if (type == tjstJob)
     pjob = find_job(preq->rq_ind.rq_status.rq_id);
   else if (type == tjstQueue)
     pjob = (job *)GET_NEXT(cntl->sc_pque->qu_jobs);
+  else if (type == tjstSummarizeArraysQueue)
+    pjob = (job *)GET_NEXT(cntl->sc_pque->qu_jobs_array_sum);
+  else if (type == tjstSummarizeArraysServer)
+    pjob = (job *)GET_NEXT(svr_jobs_array_sum);
+  else if (type == tjstArray)
+    {
+    job_array_index = 0;
+    pjob = NULL;
+    /* increment job_array_index until we find a non-null pointer or hit the end */
+    while (job_array_index < pa->ai_qs.array_size && (pjob = pa->jobs[job_array_index]) == NULL)
+        job_array_index++;
+    }
   else
     pjob = (job *)GET_NEXT(svr_alljobs);
 
@@ -638,44 +704,24 @@ nextjob:
 
     if (type == tjstQueue)
       pjob = (job *)GET_NEXT(pjob->ji_jobque);
+    else if (type == tjstSummarizeArraysQueue)
+      pjob = (job *)GET_NEXT(pjob->ji_jobque_array_sum);
+    else if (type == tjstSummarizeArraysServer)
+      pjob = (job *)GET_NEXT(pjob->ji_jobs_array_sum);
+    else if (type == tjstArray)
+      {
+      pjob = NULL;
+      /* increment job_array_index until we find a non-null pointer or hit the end */
+      while (++job_array_index < pa->ai_qs.array_size && (pjob = pa->jobs[job_array_index]) == NULL)
+        ;
+      }
     else
       pjob = (job *)GET_NEXT(pjob->ji_alljobs);
 
     rc = 0;
     }  /* END while (pjob != NULL) */
 
-  /* add completed jobs */
-
-  cpjob = NULL;  /* disable completed job display for now */
-
-  while (cpjob != NULL)
-    {
-    /* go ahead and build the status reply for this job */
-
-    pal = (svrattrl *)GET_NEXT(preq->rq_ind.rq_status.rq_attr);
-
-    rc = status_job(pjob, preq, pal, &preply->brp_un.brp_status, &bad);
-
-    if (rc && (rc != PBSE_PERM))
-      {
-      req_reject(rc, bad, preq, NULL, NULL);
-
-      return;
-      }
-
-    /* get next job */
-
-    if (type == tjstJob)
-      break;
-
-    if (type == tjstQueue)
-      pjob = (job *)GET_NEXT(pjob->ji_jobque);
-    else
-      pjob = (job *)GET_NEXT(pjob->ji_alljobs);
-
-    rc = 0;
-    }  /* END while (cpjob != NULL) */
-
+ 
   reply_send(preq);
 
   return;
@@ -831,6 +877,14 @@ static void stat_update(
           svr_mailowner(pjob, MAIL_BEGIN, MAIL_NORMAL, NULL);
           }
 
+#ifdef USESAVEDRESOURCES
+        else
+          {
+          /* save so we can recover resources used */
+          job_save(pjob, SAVEJOB_FULL);
+          }
+#endif    /* USESAVEDRESOURCES */
+
 #ifdef USESAVEDRESOURCES
         else
           {
