@@ -109,6 +109,7 @@
 #include "svrfunc.h"
 #include "rpp.h"
 #include "mcom.h"
+#include "array.h"
 
 #if __STDC__ != 1
 #include <memory.h>
@@ -121,10 +122,10 @@
 
 /* External functions called */
 
-extern void stat_mom_job A_((job *));
+extern void stat_mom_job(job *);
 extern void remove_stagein(job *);
 extern void remove_checkpoint(job *);
-extern int  job_route A_((job *));
+extern int  job_route(job *);
 
 extern struct pbsnode *PGetNodeFromAddr(pbs_net_t);
 
@@ -132,12 +133,12 @@ extern struct pbsnode *PGetNodeFromAddr(pbs_net_t);
 
 /* Private Functions local to this file */
 
-static int  local_move A_((job *, struct batch_request *));
-static void net_move_die A_((int sig));
-static void post_movejob A_((struct work_task *));
-static void post_routejob A_((struct work_task *));
-static int should_retry_route A_((int err));
-static int move_job_file A_((int con, job *pjob, enum job_file which));
+static int  local_move(job *, struct batch_request *);
+static void net_move_die(int sig);
+static void post_movejob(struct work_task *);
+static void post_routejob(struct work_task *);
+static int should_retry_route(int err);
+static int move_job_file(int con, job *pjob, enum job_file which);
 
 /* Global Data */
 
@@ -161,7 +162,7 @@ extern time_t pbs_tcp_timeout;
 extern int resc_access_perm;
 extern int      LOGLEVEL;
 
-int net_move A_((job *, struct batch_request *));
+int net_move(job *, struct batch_request *);
 
 /*
  * svr_movejob
@@ -303,7 +304,7 @@ static int local_move(
 
   strcpy(jobp->ji_qs.ji_queue, destination);
 
-  jobp->ji_wattr[(int)JOB_ATR_qrank].at_val.at_long = ++queue_rank;
+  jobp->ji_wattr[JOB_ATR_qrank].at_val.at_long = ++queue_rank;
 
   pbs_errno = svr_enquejob(jobp);
 
@@ -563,7 +564,7 @@ int send_job(
   pbs_net_t  hostaddr, /* host address, host byte order */
   int        port, /* service port, host byte order */
   int        move_type, /* move, route, or execute */
-  void (*post_func) A_((struct work_task *)),     /* after move */
+  void (*post_func)(struct work_task *),     /* after move */
   void      *data)  /* ptr to optional batch_request to be put */
                     /* in the work task structure */
 
@@ -578,6 +579,8 @@ int send_job(
 
   char  *id = "send_job";
 
+  char   job_id[PBS_MAXSVRJOBID + 1];
+
   attribute *pattr;
 
   pid_t  pid;
@@ -772,11 +775,11 @@ int send_job(
 
   pattr = jobp->ji_wattr;
 
-  for (i = 0;i < (int)JOB_ATR_LAST;i++)
+  for (i = 0;i < JOB_ATR_LAST;i++)
     {
     if (((job_attr_def + i)->at_flags & resc_access_perm) ||
       ((strncmp((job_attr_def + i)->at_name,"session_id",10) == 0) &&
-      (jobp->ji_wattr[(int)JOB_ATR_checkpoint_name].at_flags & ATR_VFLAG_SET)))
+      (jobp->ji_wattr[JOB_ATR_checkpoint_name].at_flags & ATR_VFLAG_SET)))
       {
       (job_attr_def + i)->at_encode(
         pattr + i,
@@ -793,7 +796,7 @@ int send_job(
 
   strcpy(script_name, path_jobs);
 
-  if (jobp->ji_wattr[(int)JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET)
+  if (jobp->ji_wattr[JOB_ATR_job_array_request].at_flags & ATR_VFLAG_SET)
     {
     strcat(script_name, jobp->ji_arraystruct->ai_qs.fileprefix);
     }
@@ -804,6 +807,9 @@ int send_job(
 
   strcat(script_name, JOB_SCRIPT_SUFFIX);
 
+  /* save the job id for when after we purge the job */
+
+  strcpy(job_id, jobp->ji_qs.ji_jobid);
 
   pbs_errno = 0;
   con = -1;
@@ -880,7 +886,7 @@ int send_job(
                   pqjatr,
                   NULL)) == NULL)
         {
-        if ((pbs_errno == PBSE_EXPIRED) || (pbs_errno == PBSE_READ_REPLY_TIMEOUT))
+        if (pbs_errno == PBSE_EXPIRED)
           {
           /* queue job timeout based on pbs_tcp_timeout */
 
@@ -956,7 +962,7 @@ int send_job(
         log_err(errno, id, "sigprocmask\n");
       }
 
-    if (PBSD_rdytocmt(con, jobp->ji_qs.ji_jobid) != 0)
+    if (PBSD_rdytocmt(con, job_id) != 0)
       {
       if (sigprocmask(SIG_UNBLOCK, &all_set, NULL) == -1)
         log_err(errno, id, "sigprocmask\n");
@@ -964,8 +970,15 @@ int send_job(
       continue;
       }
 
+    /*
+     * we are sure that the other side has everything, so we can
+     * safely purge the job
+     */
 
-    if ((rc = PBSD_commit(con, jobp->ji_qs.ji_jobid)) != 0)
+    if (move_type != MOVE_TYPE_Exec) /* not if sending to MOM */
+      job_purge(jobp);
+
+    if ((rc = PBSD_commit(con, job_id)) != 0)
       {
       int errno2;
 
@@ -1012,7 +1025,7 @@ int send_job(
 
         exit(1);
         }
-      }    /* END if ((rc = PBSD_commit(con,jobp->ji_qs.ji_jobid)) != 0) */
+      }    /* END if ((rc = PBSD_commit(con,job_id)) != 0) */
 
     svr_disconnect(con);
 
@@ -1106,7 +1119,7 @@ int net_move(
   char  *hostname;
   int   move_type;
   unsigned int  port = pbs_server_port_dis;
-  void (*post_func) A_((struct work_task *));
+  void (*post_func)(struct work_task *);
   char  *toserver;
   char  *id = "net_move";
 
